@@ -553,9 +553,10 @@ int getNextFragment(void) {
 
   bool end = false, any = false;
 
-  // Feed has dried up completely
-  if (step <= 256) usleep(50000);
+  // This seems to be necessary. Not sure why.
+  usleep(1000);
 
+  // Read all data in pipe
   while(pipeBufferUsed < BUFFERSIZE) {
     int result = read(pipeIn,pipeBuffer+pipeBufferUsed,BUFFERSIZE-pipeBufferUsed);
     if (result == 0)
@@ -564,6 +565,11 @@ int getNextFragment(void) {
       break;
     pipeBufferUsed += result;
   }
+  
+  //printf("%d\n",pipeBufferUsed);
+  //if (pipeBufferUsed == BUFFERSIZE) {
+  //    delay += 10000;
+  //}
     
   int eat = pipeBufferUsed - pipeBufferDelay;
 
